@@ -31,6 +31,7 @@
 #include <stdarg.h>
 #include <assert.h>
 #include <curses.h>
+#include <locale.h>
 
 #include <wordexp.h>
 #include <getopt.h>
@@ -208,6 +209,7 @@ char fullpath_exe[MAXPATHLEN + 1];
 char exe[MAXPATHLEN + 1];
 ssize_t len;
 int pid_count=0;
+int res;
 
 proc=opendir(PROC_PATH);
 if (!proc) {
@@ -226,7 +228,11 @@ while ((direntp = readdir(proc)) != NULL) {
     }
 
     if ((S_ISDIR(stat_buf.st_mode) && is_numeric(direntp->d_name))) {
-        snprintf(fullpath_exe, MAXPATHLEN, "%s/exe", fullpath_dir);
+        res = snprintf(fullpath_exe, MAXPATHLEN, "%s/exe", fullpath_dir);
+        if (res < 0) {
+            fprintf(stderr, "path is too long: %s\n", fullpath_dir);
+            exit(EXIT_FAILURE);
+        }
         len=readlink(fullpath_exe, exe, MAXPATHLEN);
         if (len != -1)
             exe[len] = 0;
@@ -304,6 +310,7 @@ char link_dest[MAXPATHLEN + 1];
 struct stat stat_buf;
 int count = 0;
 ssize_t len;
+int res;
 
 snprintf(path_dir, MAXPATHLEN, "%s/%d/fd", PROC_PATH, pid);
 
@@ -315,7 +322,11 @@ if (!proc) {
 }
 
 while ((direntp = readdir(proc)) != NULL) {
-    snprintf(fullpath, MAXPATHLEN, "%s/%s", path_dir, direntp->d_name);
+    res = snprintf(fullpath, MAXPATHLEN, "%s/%s", path_dir, direntp->d_name);
+    if (res < 0) {
+        fprintf(stderr, "path is too long: %s/%s\n", path_dir, direntp->d_name);
+        exit(EXIT_FAILURE);
+    }
     if (stat(fullpath, &stat_buf) == -1) {
         if (flag_debug)
             nperror("stat (find_fd_for_pid)");
@@ -701,7 +712,6 @@ signed char search_all = 1;
 static signed char first_pass = 1;
 
 pid_count = 0;
-
 if (!flag_monitor && !flag_monitor_continuous)
     first_pass = 0;
 
@@ -943,6 +953,7 @@ parse_options(argc,argv);
 // ws.ws_row, ws.ws_col
 ioctl(STDOUT_FILENO, TIOCGWINSZ, &ws);
 if (flag_monitor || flag_monitor_continuous) {
+    setlocale(LC_CTYPE, "");
     if ((mainwin = initscr()) == NULL ) {
         fprintf(stderr, "Error initialising ncurses.\n");
         exit(EXIT_FAILURE);
